about summary refs log tree commit diff
path: root/sysdeps/unix
diff options
context:
space:
mode:
authorUlrich Drepper <drepper@redhat.com>2000-10-18 20:46:52 +0000
committerUlrich Drepper <drepper@redhat.com>2000-10-18 20:46:52 +0000
commitb26a9120ece3e524844815c43c640fc128dd3928 (patch)
tree2a518a00ab3c91b521ce2e22e50f8f98b94b0ffe /sysdeps/unix
parentcd3cd00ccbc59d0b26909aab93f5345541f7aaf4 (diff)
downloadglibc-b26a9120ece3e524844815c43c640fc128dd3928.tar.gz
glibc-b26a9120ece3e524844815c43c640fc128dd3928.tar.xz
glibc-b26a9120ece3e524844815c43c640fc128dd3928.zip
Correct default mount point in comments. (freeit): Remove unnecessary test.
Diffstat (limited to 'sysdeps/unix')
-rw-r--r--sysdeps/unix/sysv/linux/shm_open.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/sysdeps/unix/sysv/linux/shm_open.c b/sysdeps/unix/sysv/linux/shm_open.c
index 271b92db61..713a47155a 100644
--- a/sysdeps/unix/sysv/linux/shm_open.c
+++ b/sysdeps/unix/sysv/linux/shm_open.c
@@ -54,7 +54,7 @@ where_is_shmfs (void)
   struct mntent *mp;
   FILE *fp;
 
   /* The canonical place is /var/shm.  This is at least what the
      documentation tells everybody to do.  */
   if (__statfs (defaultdir, &f) == 0 && f.f_type == SHMFS_SUPER_MAGIC)
     {
@@ -116,7 +116,7 @@ where_is_shmfs (void)
 
 /* Open shared memory object.  This implementation assumes the shmfs
    implementation introduced in the late 2.3.x kernel series to be
-   available.  Normally the filesystem will be mounted at /var/shm but
+   available.  Normally the filesystem will be mounted at /dev/shm but
    we fall back on searching for the actual mount point should opening
    such a file fail.  */
 int
@@ -230,7 +230,7 @@ shm_unlink (const char *name)
 void
 freeit (void)
 {
-  if (mountpoint.dir != NULL && mountpoint.dir != defaultdir)
+  if (mountpoint.dir != defaultdir)
     free (mountpoint.dir);
 }
@@ -54,7 +54,7 @@ where_is_shmfs (void)
   FILE *fp;
 
-  /* The canonical place is /var/shm.  This is at least what the
+  /* The canonical place is /dev/shm.  This is at least what the
      documentation tells everybody to do.  */
   if (__statfs (defaultdir, &f) == 0 && f.f_type == SHMFS_SUPER_MAGIC)